ipecharts.option.seriesitems.effectscatter module
=================================================

.. automodule:: ipecharts.option.seriesitems.effectscatter
   :members:
   :undoc-members:
   :show-inheritance:
